@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Pod::Eventual::Simple;
-our $VERSION = '0.091470';
+our $VERSION = '0.091480';
 
 use Pod::Eventual;
 BEGIN { our @ISA = 'Pod::Eventual' }
@@ -25,11 +25,9 @@ sub handle_event {
   push @$self, $event;
 }
 
-BEGIN { *handle_blank = \&handle_event; }
-
-sub handle_nonpod {
-  my ($self, $line, $ln) = @_;
-  push @$self, { type => 'nonpod', content => $line, start_line => $ln };
+BEGIN {
+  *handle_blank  = \&handle_event;
+  *handle_nonpod = \&handle_event;
 }
 
 1;
@@ -44,23 +42,23 @@ Pod::Eventual::Simple - just get an array of the stuff Pod::Eventual finds
 
 =head1 VERSION
 
-version 0.091470
+version 0.091480
 
 =head1 SYNOPSIS
 
-    use Pod::Eventual::Simple;
+  use Pod::Eventual::Simple;
 
-    my $output = Pod::Eventual::Simple->read_file('awesome.pod');
+  my $output = Pod::Eventual::Simple->read_file('awesome.pod');
 
 This subclass just returns an array reference when you use the reading methods.
 The arrayref contains all the Pod events and non-Pod content.  Non-Pod content
 is given as hashrefs like this:
 
-    {
-      type       => 'nonpod',
-      content    => "This is just some text\n",
-      start_line => 162,
-    }
+  {
+    type       => 'nonpod',
+    content    => "This is just some text\n",
+    start_line => 162,
+  }
 
 For just the POD events, grep for C<type> not equals "nonpod"
 
